@@ -3,7 +3,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: Find the top repeated note phrases of a MIDI file
 
-our $VERSION = '0.02';
+our $VERSION = '0.03';
 
 use Moo;
 use strictures 2;
@@ -27,35 +27,35 @@ has file => (
 
 has size => (
     is      => 'ro',
-    isa     => sub { croak 'Invalid integer' unless $_[0] && $_[0] =~ /^\d+$/ && $_[0] > 0 },
+    isa     => \&_invalid_integer,
     default => sub { 2 },
 );
 
 
 has max => (
     is      => 'ro',
-    isa     => sub { croak 'Invalid integer' unless $_[0] && $_[0] =~ /^\d+$/ && $_[0] > 0 },
+    isa     => \&_invalid_integer,
     default => sub { 10 },
 );
 
 
 has bpm => (
     is      => 'ro',
-    isa     => sub { croak 'Invalid integer' unless $_[0] && $_[0] =~ /^\d+$/ && $_[0] > 0 },
+    isa     => \&_invalid_integer,
     default => sub { 100 },
 );
 
 
 has durations => (
     is      => 'ro',
-    isa     => sub { croak 'Invalid list' unless ref $_[0] eq 'ARRAY' },
+    isa     => \&_invalid_list,
     default => sub { [qw( qn tqn )] },
 );
 
 
 has patches => (
     is      => 'ro',
-    isa     => sub { croak 'Invalid list' unless ref $_[0] eq 'ARRAY' },
+    isa     => \&_invalid_list,
     default => sub { [ 0 .. 127 ] },
 );
 
@@ -75,42 +75,42 @@ has pause => (
 
 has loop => (
     is      => 'ro',
-    isa     => sub { croak 'Invalid integer' unless $_[0] && $_[0] =~ /^\d+$/ && $_[0] > 0 },
+    isa     => \&_invalid_integer,
     default => sub { 10 },
 );
 
 
 has weight => (
     is      => 'ro',
-    isa     => sub { croak 'Invalid Boolean' unless defined $_[0] && ( $_[0] == 1 || $_[0] == 0 ) },
+    isa     => \&_invalid_boolean,
     default => sub { 0 },
 );
 
 
 has randpatch => (
     is      => 'ro',
-    isa     => sub { croak 'Invalid Boolean' unless defined $_[0] && ( $_[0] == 1 || $_[0] == 0 ) },
+    isa     => \&_invalid_boolean,
     default => sub { 0 },
 );
 
 
 has shuffle_phrases => (
     is      => 'ro',
-    isa     => sub { croak 'Invalid Boolean' unless defined $_[0] && ( $_[0] == 1 || $_[0] == 0 ) },
+    isa     => \&_invalid_boolean,
     default => sub { 0 },
 );
 
 
 has single => (
     is      => 'ro',
-    isa     => sub { croak 'Invalid Boolean' unless defined $_[0] && ( $_[0] == 1 || $_[0] == 0 ) },
+    isa     => \&_invalid_boolean,
     default => sub { 0 },
 );
 
 
 has verbose => (
     is      => 'ro',
-    isa     => sub { croak 'Invalid Boolean' unless defined $_[0] && ( $_[0] == 1 || $_[0] == 0 ) },
+    isa     => \&_invalid_boolean,
     default => sub { 0 },
 );
 
@@ -377,6 +377,21 @@ sub _set_chan_patch {
     $score->noop( 'c' . $channel );
 }
 
+sub _invalid_integer {
+    croak 'Invalid integer'
+        unless $_[0] && $_[0] =~ /^\d+$/ && $_[0] > 0;
+}
+
+sub _invalid_list {
+    croak 'Invalid list'
+        unless ref $_[0] eq 'ARRAY';
+}
+
+sub _invalid_boolean {
+    croak 'Invalid Boolean'
+        unless defined $_[0] && ( $_[0] == 1 || $_[0] == 0 );
+}
+
 1;
 
 __END__
@@ -391,7 +406,7 @@ MIDI::Ngram - Find the top repeated note phrases of a MIDI file
 
 =head1 VERSION
 
-version 0.02
+version 0.03
 
 =head1 SYNOPSIS
 
